@@ -41,6 +41,7 @@ program packmol
   use flashsort
   use swaptypemod
   use ahestetic
+  use pbc
   implicit none
 
   integer :: itype, irest, idatom, iatom
@@ -346,6 +347,13 @@ program packmol
             iratom(icart,iratcount) = iirest
           end if
         end do
+        if (using_pbc) then
+          nratom(icart) = nratom(icart) + 1
+          iratcount = iratcount + 1
+          do irest = 1, nrest
+            if (irestline(irest).eq.-1) iratom(icart,iratcount) = irest
+          end do
+        end if
         if(nratom(icart).gt.0) rests = .true.
       end do 
       if(.not.rests) then
@@ -670,13 +678,13 @@ program packmol
   if(n.eq.0) then
     call output(n,x, xyzout)
     write(*,dash1_line)
-    write(*,*) ' There are only fixed molecules, therefore there is nothing to do. '
+    write(*,*) ' Success! There are only fixed molecules, therefore there is nothing to pack. '
     write(*,*) ' The output file contains the fixed molecules in the desired positions. '
     write(*,dash1_line)
     write(*,*) ' Wrote output file: ', trim(adjustl(xyzout))
     if ( crd ) write(*,*) ' ... and to CRD file: ', trim(adjustl(crdfile))
     write(*,dash1_line)
-    stop exit_code_input_error
+    stop
   end if
   
   !
