@@ -1,6 +1,13 @@
-#!/bin/bash
 ####################################################################################################
 
+#
+# How to release the software:
+#
+# run ./release. 20.14.1 (for example)
+#
+# go to the github site and release the version corresponding to the new tag.
+#
+
 # Software name:
 
 package=packmol
@@ -31,9 +38,6 @@ if [[ $version < " " ]]; then
   exit
 fi
 
-file="$package-$version.tar.gz" 
-echo "Will create file: $file"
-
 cat $versionfile | sed -e "s/Version.*/Version\ $version \')\")/" > tmpfile.txt
 \mv -f tmpfile.txt $versionfile
 
@@ -52,5 +56,4 @@ range=`git tag | sort -V | tail -n 2 | xargs | sed 's! !...!'`
 git log --pretty=oneline $range | awk '{$1=""; print "-"$0}'
 echo "----------------------"
 
-echo " Done. " 
-
+echo " Done. "   
\ No newline at end of file
